@@ -77,6 +77,7 @@ API_APPS_ENDPOINTS = dict(
         "prefixes",
         "rirs",
         "roles",
+        "route_targets",
         "vlans",
         "vlan_groups",
         "vrfs",
@@ -98,8 +99,10 @@ QUERY_TYPES = dict(
     device="name",
     device_role="slug",
     device_type="slug",
+    export_targets="name",
     group="slug",
     installed_device="name",
+    import_targets="name",
     manufacturer="slug",
     nat_inside="address",
     nat_outside="address",
@@ -119,6 +122,7 @@ QUERY_TYPES = dict(
     rear_port_template="name",
     region="slug",
     rir="slug",
+    route_targets="name",
     slug="slug",
     site="slug",
     tenant="slug",
@@ -153,7 +157,9 @@ CONVERT_TO_ID = {
     "device": "devices",
     "device_role": "device_roles",
     "device_type": "device_types",
+    "export_targets": "route_targets",
     "group": "tenant_groups",
+    "import_targets": "route_targets",
     "installed_device": "devices",
     "interface": "interfaces",
     "interface_template": "interface_templates",
@@ -180,6 +186,7 @@ CONVERT_TO_ID = {
     "rear_port": "rear_ports",
     "rear_port_template": "rear_port_templates",
     "rir": "rirs",
+    "route_targets": "route_targets",
     "services": "services",
     "site": "sites",
     "tags": "tags",
@@ -240,6 +247,7 @@ ENDPOINT_NAME_MAPPING = {
     "regions": "region",
     "rirs": "rir",
     "roles": "role",
+    "route_targets": "route_target",
     "services": "services",
     "sites": "site",
     "tags": "tags",
@@ -285,7 +293,7 @@ ALLOWED_QUERY_PARAMS = {
     "interface": set(["name", "device", "virtual_machine"]),
     "interface_template": set(["name", "device_type"]),
     "inventory_item": set(["name", "device"]),
-    "ip_address": set(["address", "vrf", "interface"]),
+    "ip_address": set(["address", "vrf", "device", "interface"]),
     "ip_addresses": set(["address", "vrf", "device", "interface"]),
     "ipaddresses": set(["address", "vrf", "device", "interface"]),
     "lag": set(["name"]),
@@ -312,6 +320,7 @@ ALLOWED_QUERY_PARAMS = {
     "rear_port_template": set(["name", "device_type"]),
     "rir": set(["slug"]),
     "role": set(["slug"]),
+    "route_target": set(["name"]),
     "services": set(["device", "virtual_machine", "name", "port", "protocol"]),
     "site": set(["slug"]),
     "tags": set(["slug"]),
@@ -701,8 +710,17 @@ class NetboxModule(object):
         elif parent == "prefix" and module_data.get("parent"):
             query_dict.update({"prefix": module_data["parent"]})
 
-        # This is for netbox_ipam and netbox_ip_address module
-        elif parent == "ip_address" and module_data.get("assigned_object_type"):
+        elif parent == "ip_addresses":
+            if isinstance(module_data["device"], int):
+                query_dict.update({"device_id": module_data["device"]})
+            else:
+                query_dict.update({"device": module_data["device"]})
+
+        elif (
+            parent == "ip_address"
+            and "assigned_object" in matches
+            and module_data.get("assigned_object_type")
+        ):
             if module_data["assigned_object_type"] == "virtualization.vminterface":
                 query_dict.update(
                     {"vminterface_id": module_data.get("assigned_object_id")}
@@ -712,12 +730,6 @@ class NetboxModule(object):
                     {"interface_id": module_data.get("assigned_object_id")}
                 )
 
-        elif parent == "ip_addresses":
-            if isinstance(module_data["device"], int):
-                query_dict.update({"device_id": module_data["device"]})
-            else:
-                query_dict.update({"device": module_data["device"]})
-
         elif parent == "virtual_chassis":
             query_dict = {"q": self.module.params["data"].get("master")}
 
@@ -741,6 +753,15 @@ class NetboxModule(object):
             if query_dict.get("device_type"):
                 query_dict["devicetype_id"] = query_dict.pop("device_type")
 
+        if not query_dict:
+            provided_kwargs = child.keys() if child else module_data.keys()
+            acceptable_query_params = (
+                user_query_params if user_query_params else query_params
+            )
+            self._handle_errors(
+                f"One or more of the kwargs provided are invalid for {parent}, provided kwargs: {', '.join(sorted(provided_kwargs))}. Acceptable kwargs: {', '.join(sorted(acceptable_query_params))}"
+            )
+
         query_dict = self._convert_identical_keys(query_dict)
         return query_dict
 
@@ -840,6 +861,14 @@ class NetboxModule(object):
                             temp_dict = self._build_query_params(
                                 k, data, child=norm_data
                             )
+                        # If user passes in an integer, add to ID list to id_list as user
+                        # should have passed in a tag ID
+                        elif isinstance(list_item, int):
+                            id_list.append(list_item)
+                            continue
+                        else:
+                            temp_dict = {QUERY_TYPES.get(k, "q"): search}
+
                         query_id = self._nb_endpoint_get(nb_endpoint, temp_dict, k)
                         if query_id:
                             id_list.append(query_id.id)
